aboutsummaryrefslogtreecommitdiff
path: root/src/args.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/args.rs')
-rw-r--r--src/args.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/args.rs b/src/args.rs
index 6fdca59..fe74f5e 100644
--- a/src/args.rs
+++ b/src/args.rs
@@ -33,9 +33,9 @@ pub struct Args {
#[arg(short = 'l', long = "legende", action = ArgAction::SetTrue)]
pub legende: bool,
- /// Print the remainder line
- #[arg(short = 'r', long = "remainder", action = ArgAction::SetTrue)]
- pub remainder: bool,
+ /// Print the status line, the given target and the IP the ping is send to.
+ #[arg(long = "status", action = ArgAction::SetTrue)]
+ pub status: bool,
/// Default target, if none is specified
#[arg(long = "default-target", value_name = "default_target")]